==> haskell-tls-session-manager-0.0.0.2-90-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-22OooSIhRDV4NBfi7KbxfW
key: tls-session-manager-0.0.0.2-22OooSIhRDV4NBfi7KbxfW
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: 74f2979bb1b5d717a1fce5fa322e0934
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.4/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-22OooSIhRDV4NBfi7KbxfW
depends:
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3
    tls-1.4.1-Kg6JuQQHCkG9xz0nXASBgS
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.2-91-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-LTMw46S7ShQ8rz3lgwWQf3
key: tls-session-manager-0.0.0.2-LTMw46S7ShQ8rz3lgwWQf3
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: f8315763b42fe1779fc9bbdb615bdcb5
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.4/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-LTMw46S7ShQ8rz3lgwWQf3
depends:
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3
    tls-1.4.1-F46ATC24WHHLIGPvj7MfBw
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
